@@ -56,7 +56,7 @@ static QString localTmpDir()
 
 static bool myExists(const QUrl &url)
 {
-    KIO::Job *job = KIO::statDetails(url, KIO::StatJob::DestinationSide, KIO::StatBasic, KIO::HideProgressInfo);
+    KIO::Job *job = KIO::stat(url, KIO::StatJob::DestinationSide, KIO::StatBasic, KIO::HideProgressInfo);
     job->setUiDelegate(nullptr);
     return job->exec();
 }
@@ -183,12 +183,7 @@ void JobRemoteTest::openFileWriting()
     connect(fileJob, &KIO::FileJob::open, this, &JobRemoteTest::slotFileJobOpen);
     connect(fileJob, &KIO::FileJob::written, this, &JobRemoteTest::slotFileJobWritten);
     connect(fileJob, &KIO::FileJob::position, this, &JobRemoteTest::slotFileJobPosition);
-
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
-    connect(fileJob, qOverload<KIO::Job *>(&KIO::FileJob::close), this, &JobRemoteTest::slotFileJobClose);
-#else
     connect(fileJob, &KIO::FileJob::fileClosed, this, &JobRemoteTest::slotFileJobClose);
-#endif
 
     m_result = -1;
     m_closeSignalCalled = false;
@@ -291,11 +286,7 @@ void JobRemoteTest::openFileReading()
     connect(fileJob, &KIO::FileJob::position, this, &JobRemoteTest::slotFileJob2Position);
 
     // Can reuse this slot (same for all tests).
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
-    connect(fileJob, qOverload<KIO::Job *>(&KIO::FileJob::close), this, &JobRemoteTest::slotFileJobClose);
-#else
     connect(fileJob, &KIO::FileJob::fileClosed, this, &JobRemoteTest::slotFileJobClose);
-#endif
 
     m_result = -1;
     m_closeSignalCalled = false;
@@ -390,11 +381,7 @@ void JobRemoteTest::openFileRead0Bytes()
     connect(fileJob, &KIO::FileJob::position, this, &JobRemoteTest::slotFileJob3Position);
 
     // Can reuse this as well.
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
-    connect(fileJob, qOverload<KIO::Job *>(&KIO::FileJob::close), this, &JobRemoteTest::slotFileJobClose);
-#else
     connect(fileJob, &KIO::FileJob::fileClosed, this, &JobRemoteTest::slotFileJobClose);
-#endif
 
     m_result = -1;
     m_closeSignalCalled = false;
@@ -454,11 +441,7 @@ void JobRemoteTest::openFileTruncating()
     connect(fileJob, &KIO::FileJob::truncated, this, &JobRemoteTest::slotFileJob4Truncated);
 
     // Can reuse this slot (same for all tests).
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 79)
-    connect(fileJob, qOverload<KIO::Job *>(&KIO::FileJob::close), this, &JobRemoteTest::slotFileJobClose);
-#else
     connect(fileJob, &KIO::FileJob::fileClosed, this, &JobRemoteTest::slotFileJobClose);
-#endif
 
     m_result = -1;
     m_closeSignalCalled = false;
@@ -495,3 +478,5 @@ void JobRemoteTest::slotFileJob4Truncated(KIO::Job *job, KIO::filesize_t length)
         qDebug() << "Truncating file finished";
     }
 }
+
+#include "moc_jobremotetest.cpp"
