@@ -24,6 +24,7 @@
 #include <kurlnavigator.h>
 
 #include <KLocalizedString>
+#include <KWindowSystem>
 
 #include <QAbstractItemView>
 #include <QDialog>
@@ -162,6 +163,10 @@ void KFileWidgetTest::testFilterCombo()
 
 void KFileWidgetTest::testFocusOnLocationEdit()
 {
+    if (KWindowSystem::isPlatformWayland()) {
+        QSKIP("X11 only, activation issue");
+        return;
+    }
     KFileWidget fw(QUrl::fromLocalFile(QDir::homePath()));
     fw.show();
     fw.activateWindow();
@@ -174,6 +179,10 @@ void KFileWidgetTest::testFocusOnLocationEdit()
 
 void KFileWidgetTest::testFocusOnLocationEditChangeDir()
 {
+    if (KWindowSystem::isPlatformWayland()) {
+        QSKIP("X11 only, activation issue");
+        return;
+    }
     KFileWidget fw(QUrl::fromLocalFile(QDir::homePath()));
     fw.setUrl(QUrl::fromLocalFile(QDir::tempPath()));
     fw.show();
@@ -187,6 +196,10 @@ void KFileWidgetTest::testFocusOnLocationEditChangeDir()
 
 void KFileWidgetTest::testFocusOnLocationEditChangeDir2()
 {
+    if (KWindowSystem::isPlatformWayland()) {
+        QSKIP("X11 only, activation issue");
+        return;
+    }
     KFileWidget fw(QUrl::fromLocalFile(QDir::homePath()));
     fw.show();
     fw.activateWindow();
@@ -201,6 +214,10 @@ void KFileWidgetTest::testFocusOnLocationEditChangeDir2()
 
 void KFileWidgetTest::testFocusOnDirOps()
 {
+    if (KWindowSystem::isPlatformWayland()) {
+        QSKIP("X11 only, activation issue");
+        return;
+    }
     KFileWidget fw(QUrl::fromLocalFile(QDir::homePath()));
     fw.show();
     fw.activateWindow();
