@@ -7,9 +7,9 @@
 #ifndef HOSTINFO_H_
 #define HOSTINFO_H_
 
-#include <QString>
-#include <QObject>
 #include "kiocore_export.h"
+#include <QObject>
+#include <QString>
 
 class QHostInfo;
 
@@ -20,24 +20,21 @@ namespace KIO
  * WARNING: this could disappear at some point in time.
  * DO NOT USE outside KDE Frameworks
  */
+/*
+ * TODO KF6: This header is intenionally not installed in KF6, and we should look into unexporting
+ * and removing most of these functions; they are only used internally in very few places where
+ * they might even be inlined to.
+ */
 namespace HostInfo
 {
 /// @internal
-KIOCORE_EXPORT void lookupHost(const QString &hostName, QObject *receiver, const char *member);
+void lookupHost(const QString &hostName, QObject *receiver, const char *member);
 /// @internal
 KIOCORE_EXPORT QHostInfo lookupHost(const QString &hostName, unsigned long timeout);
 /// @internal
 KIOCORE_EXPORT QHostInfo lookupCachedHostInfoFor(const QString &hostName);
 /// @internal
 KIOCORE_EXPORT void cacheLookup(const QHostInfo &info);
-
-// used by khtml's DNS prefetching feature
-/// @internal
-KIOCORE_EXPORT void prefetchHost(const QString &hostName);
-/// @internal
-KIOCORE_EXPORT void setCacheSize(int s);
-/// @internal
-KIOCORE_EXPORT void setTTL(int ttl);
 }
 }
 
