@@ -1,46 +1,36 @@
-/* This file is part of the KDE project
-   Copyright (c) 2004 Jan Schaefer <j_schaef@informatik.uni-kl.de>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2004 Jan Schaefer <j_schaef@informatik.uni-kl.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "knfsshare.h"
 
+#include "../utils_p.h"
+
+#include <QDebug>
+#include <QFile>
 #include <QFileInfo>
 #include <QSet>
-#include <QFile>
-#include <QMutableStringListIterator>
 #include <QTextStream>
-#include <QDebug>
 
-#include <kdirwatch.h>
-#include <kconfig.h>
-#include <kconfiggroup.h>
 #include "kiocoredebug.h"
+#include <KConfig>
+#include <KConfigGroup>
+#include <KDirWatch>
 
 class Q_DECL_HIDDEN KNFSShare::KNFSSharePrivate
 {
 public:
     explicit KNFSSharePrivate(KNFSShare *parent);
 
-    void _k_slotFileChange(const QString &);
+    void slotFileChange(const QString &);
 
     bool readExportsFile();
     bool findExportsFile();
 
-    KNFSShare * const q;
+    KNFSShare *const q;
     QSet<QString> sharedPaths;
     QString exportsFile;
 };
@@ -62,7 +52,7 @@ KNFSShare::KNFSSharePrivate::KNFSSharePrivate(KNFSShare *parent)
 bool KNFSShare::KNFSSharePrivate::findExportsFile()
 {
     KConfig knfsshare(QStringLiteral("knfsshare"));
-    KConfigGroup config(&knfsshare, "General");
+    KConfigGroup config(&knfsshare, QStringLiteral("General"));
     exportsFile = config.readPathEntry("exportsFile", QString());
 
     if (!exportsFile.isEmpty() && QFileInfo::exists(exportsFile)) {
@@ -72,7 +62,7 @@ bool KNFSShare::KNFSSharePrivate::findExportsFile()
     if (QFile::exists(QStringLiteral("/etc/exports"))) {
         exportsFile = QStringLiteral("/etc/exports");
     } else {
-        //qDebug() << "Could not find exports file! /etc/exports doesn't exist. Configure it in share/config/knfsshare, [General], exportsFile=....";
+        // qDebug() << "Could not find exports file! /etc/exports doesn't exist. Configure it in share/config/knfsshare, [General], exportsFile=....";
         return false;
     }
 
@@ -88,7 +78,7 @@ bool KNFSShare::KNFSSharePrivate::readExportsFile()
 {
     QFile f(exportsFile);
 
-    //qDebug() << exportsFile;
+    // qDebug() << exportsFile;
 
     if (!f.open(QIODevice::ReadOnly)) {
         qCWarning(KIO_CORE) << "KNFSShare: Could not open" << exportsFile;
@@ -147,17 +137,13 @@ bool KNFSShare::KNFSSharePrivate::readExportsFile()
             } else {
                 path = completeLine.left(i);
             }
-
         }
 
-        //qDebug() << "KNFSShare: Found path: " << path;
+        // qDebug() << "KNFSShare: Found path: " << path;
 
         if (!path.isEmpty()) {
-            // normalize path
-            if (!path.endsWith(QLatin1Char('/'))) {
-                path += QLatin1Char('/');
-            }
-
+            // Append a '/' to normalize path
+            Utils::appendSlash(path);
             sharedPaths.insert(path);
         }
     }
@@ -170,31 +156,21 @@ KNFSShare::KNFSShare()
 {
     if (!d->exportsFile.isEmpty() && QFileInfo::exists(d->exportsFile)) {
         KDirWatch::self()->addFile(d->exportsFile);
-        connect(KDirWatch::self(), SIGNAL(dirty(QString)), this,
-                SLOT(_k_slotFileChange(QString)));
+        connect(KDirWatch::self(), &KDirWatch::dirty, this, [this](const QString &path) {
+            d->slotFileChange(path);
+        });
     }
 }
 
-KNFSShare::~KNFSShare()
-{
-    // This is not needed, we're exiting the process anyway, and KDirWatch is already deleted.
-    //if (QFile::exists(d->exportsFile)) {
-    //  KDirWatch::self()->removeFile(d->exportsFile);
-    //}
-    delete d;
-}
+KNFSShare::~KNFSShare() = default;
 
 bool KNFSShare::isDirectoryShared(const QString &path) const
 {
     if (path.isEmpty()) {
         return false;
     }
-    QString fixedPath = path;
-    if (!fixedPath.endsWith(QLatin1Char('/'))) {
-        fixedPath += QLatin1Char('/');
-    }
 
-    return d->sharedPaths.contains(fixedPath);
+    return d->sharedPaths.contains(Utils::slashAppended(path));
 }
 
 QStringList KNFSShare::sharedDirectories() const
@@ -207,13 +183,13 @@ QString KNFSShare::exportsPath() const
     return d->exportsFile;
 }
 
-void KNFSShare::KNFSSharePrivate::_k_slotFileChange(const QString &path)
+void KNFSShare::KNFSSharePrivate::slotFileChange(const QString &path)
 {
     if (path == exportsFile) {
         readExportsFile();
     }
 
-    emit q->changed();
+    Q_EMIT q->changed();
 }
 
 class KNFSShareSingleton
@@ -230,4 +206,3 @@ KNFSShare *KNFSShare::instance()
 }
 
 #include "moc_knfsshare.cpp"
-
