@@ -21,9 +21,6 @@
 class KProtocolInfoPrivate
 {
 public:
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 84)
-    explicit KProtocolInfoPrivate(const QString &path);
-#endif
     KProtocolInfoPrivate(const QString &name, const QString &exec, const QJsonObject &json);
 
     QString m_name;
@@ -61,9 +58,6 @@ public:
     KProtocolInfo::ExtraFieldList m_extraFields;
     KProtocolInfo::FileNameUsedForCopying m_fileNameUsedForCopying;
     QStringList m_capabilities;
-#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 101)
-    QStringList m_slaveHandlesNotify;
-#endif
     QString m_proxyProtocol;
     int m_maxWorkersPerHost;
 };
