@@ -117,7 +117,7 @@ void KUrlComboBoxPrivate::init(KUrlComboBox::Mode mode)
 
     opendirIcon = QIcon::fromTheme(QStringLiteral("folder-open"));
 
-    m_parent->connect(m_parent, qOverload<int>(&KUrlComboBox::activated), m_parent, [this](int index) {
+    m_parent->connect(m_parent, &KUrlComboBox::activated, m_parent, [this](int index) {
         slotActivated(index);
     });
 }
@@ -384,7 +384,7 @@ void KUrlComboBox::mousePressEvent(QMouseEvent *event)
         QStyle::visualRect(layoutDirection(), rect(), style()->subControlRect(QStyle::CC_ComboBox, &comboOpt, QStyle::SC_ComboBoxEditField, this)).x();
     const int frameWidth = style()->pixelMetric(QStyle::PM_DefaultFrameWidth, &comboOpt, this);
 
-    if (event->x() < (x0 + KIconLoader::SizeSmall + frameWidth)) {
+    if (qRound(event->position().x()) < (x0 + KIconLoader::SizeSmall + frameWidth)) {
         d->m_dragPoint = event->pos();
     } else {
         d->m_dragPoint = QPoint();
